@@ -171,6 +171,8 @@ def upload_csv(token, org_id, module, filename):
 		return upload_csv(token,org_id,module, filename)
 
 	elif response.status_code >= 400 and response.status_code < 500:
+		print(response.status_code)
+		print(response.content)
 		print("Refreshing token")
 		token.generate()
 		return upload_csv(token,org_id, module, filename)
